"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
var papaparse_1 = __importDefault(require("papaparse"));
/**
 * synonyms.txtのコンテンツ(空改行区切りのCSV)からSudachiSynonymsGroupの配列を返します
 * @param text
 */
exports.parse = function (text) {
    var synonymsList = text.trim().split(/(?:\r?\n){2}/);
    return synonymsList.map(function (synonyms) { return exports.parseSynonyms(synonyms); });
};
/**
 * グループのCSVからSudachiSynonymsGroupを返します。。
 * csv format
 * 0 : グループ番号
 * 1 : 体言/用言フラグ (省略可)
 * 2 : 展開制御フラグ (省略可)
 * 3 : グループ内の語彙番号 (省略可)
 * 4 : 同一語彙内での語形種別 (省略可)
 * 5 : 同じ語形の語の中での略語情報 (省略可)
 * 6 : 同じ語形の語の中での表記揺れ情報 (省略可)
 * 7 : 分野情報 (省略可)
 * 8 : 見出し
 * 9 : 予約
 * 10 : 予約
 * @param csv
 * @return SudachiSynonyms[]
 */
exports.parseSynonyms = function (csv) {
    var result = papaparse_1.default.parse(csv);
    return {
        // 数字じゃなくで0埋めされたidなので
        id: result.data[0][0],
        items: result.data.map(function (item) {
            var taigenYogen = item[1] === "1" ? "体言" : item[1] === "2" ? "用言" : "未定義";
            var expandControl = item[2] === undefined ? 0 : Number(item[2]);
            var vocabularyNumber = item[3] !== undefined ? Number(item[3]) : undefined;
            var gokeiSyubetsu = item[4] === "0"
                ? "代表語"
                : item[4] === "1"
                    ? "対訳"
                    : item[4] === "2"
                        ? "別称"
                        : item[4] === "3"
                            ? "旧称"
                            : item[4] === "4"
                                ? "間違い"
                                : "未定義";
            var ryakusyou = item[5] === "0"
                ? "代表語形"
                : item[5] === "1"
                    ? "略語・略称/アルファベット"
                    : item[5] === "2"
                        ? "略語・略称"
                        : "未定義";
            var hyoukiYure = item[6] === "0"
                ? "代表表記"
                : item[6] === "1"
                    ? "アルファベット表記"
                    : item[6] === "2"
                        ? "異表記・表記ゆれ"
                        : item[6] === "3"
                            ? "間違い表記"
                            : "未定義";
            var bunya = item[7] !== undefined
                ? item[7]
                    .substring(1, item[7].length - 1)
                    .split("/")
                    .filter(function (word) { return word !== ""; })
                : [];
            var midashi = item[8];
            return {
                taigenYogen: taigenYogen,
                expandControl: expandControl,
                vocabularyNumber: vocabularyNumber,
                gokeiSyubetsu: gokeiSyubetsu,
                ryakusyou: ryakusyou,
                hyoukiYure: hyoukiYure,
                bunya: bunya,
                midashi: midashi
            };
        })
    };
};
//# sourceMappingURL=sudachi-synonyms-parser.js.map